aboutsummaryrefslogtreecommitdiffstats
path: root/Frameworks/QueryKit/Source/QKQuery.h
diff options
context:
space:
mode:
authorstuconnolly <stuart02@gmail.com>2012-07-09 09:27:48 +0000
committerstuconnolly <stuart02@gmail.com>2012-07-09 09:27:48 +0000
commitc1bab7abd666d809aa01c330a66c53e1b6abe6c4 (patch)
tree075fcdeb4b371e0fd1a21e74fa14ebf705860e2e /Frameworks/QueryKit/Source/QKQuery.h
parenta434272a852db341a6ea4421e388ef924b6a99d7 (diff)
downloadsequelpro-c1bab7abd666d809aa01c330a66c53e1b6abe6c4.tar.gz
sequelpro-c1bab7abd666d809aa01c330a66c53e1b6abe6c4.tar.bz2
sequelpro-c1bab7abd666d809aa01c330a66c53e1b6abe6c4.zip
Improve QueryKit's handling of quotes by making it on by default. Also, add a bunch more tests.
Diffstat (limited to 'Frameworks/QueryKit/Source/QKQuery.h')
-rw-r--r--Frameworks/QueryKit/Source/QKQuery.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/Frameworks/QueryKit/Source/QKQuery.h b/Frameworks/QueryKit/Source/QKQuery.h
index c0f925bb..1cb93d15 100644
--- a/Frameworks/QueryKit/Source/QKQuery.h
+++ b/Frameworks/QueryKit/Source/QKQuery.h
@@ -55,7 +55,7 @@
QKQueryType _queryType;
- BOOL _quoteFields;
+ BOOL _useQuotes;
BOOL _orderDescending;
}
@@ -90,9 +90,9 @@
@property (readwrite, assign, getter=queryType, setter=setQueryType:) QKQueryType _queryType;
/**
* @property _quoteFields Indicates whether or not the query's fields should be quoted.
*/
-@property (readwrite, assign, getter=quoteFields, setter=setQuoteFields:) BOOL _quoteFields;
+@property (readwrite, assign, getter=useQuotes) BOOL _useQuotes;
+ (QKQuery *)queryTable:(NSString *)table;
+ (QKQuery *)selectQueryFromTable:(NSString *)table;
@@ -102,6 +102,8 @@
- (NSString *)query;
- (void)clear;
+- (void)setUseQuotes:(BOOL)quote;
+
- (void)addField:(NSString *)field;
- (void)addFields:(NSArray *)fields;
@@ -90,9 +90,9 @@
/**
- * @property _quoteFields Indicates whether or not the query's fields should be quoted.
+ * @property _useQuotes Indicates whether or not the query's fields should be quoted.
*/